#[repr(transparent)]pub struct SessionInfo {
inner: TypedObjectRef<SessionInfo, ()>,
phantom: PhantomData<()>,
}Expand description
Parent class of objects containing a Matrix session’s info.
Its main purpose is to be able to handle Sessions that are being initialized, or where initialization failed.
GLib type: GObject with reference counted clone semantics.
Fields
inner: TypedObjectRef<SessionInfo, ()>phantom: PhantomData<()>Implementations
Sourceimpl SessionInfo
impl SessionInfo
Sourcepub fn user_id_string(&self) -> <PhantomData<String> as Property>::Value
pub fn user_id_string(&self) -> <PhantomData<String> as Property>::Value
The Matrix session’s user ID, as a string.
Sourcepub fn homeserver_string(&self) -> <PhantomData<String> as Property>::Value
pub fn homeserver_string(&self) -> <PhantomData<String> as Property>::Value
The Matrix session’s homeserver, as a string.
Sourcepub fn device_id_string(&self) -> <PhantomData<String> as Property>::Value
pub fn device_id_string(&self) -> <PhantomData<String> as Property>::Value
The Matrix session’s device ID, as a string.
Sourcepub fn session_id(&self) -> <PhantomData<String> as Property>::Value
pub fn session_id(&self) -> <PhantomData<String> as Property>::Value
The local session’s ID.
Sourcepub fn avatar_data(&self) -> <PhantomData<AvatarData> as Property>::Value
pub fn avatar_data(&self) -> <PhantomData<AvatarData> as Property>::Value
The avatar data to represent this session.
Sourcepub fn connect_info_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_info_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the info property
Sourcepub fn connect_user_id_string_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_user_id_string_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the user-id-string property
Sourcepub fn connect_homeserver_string_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_homeserver_string_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the homeserver-string property
Sourcepub fn connect_device_id_string_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_device_id_string_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the device-id-string property
Sourcepub fn connect_session_id_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_session_id_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the session-id property
Sourcepub fn connect_avatar_data_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_avatar_data_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the avatar-data property
Sourcepub fn notify_info(&self)
pub fn notify_info(&self)
Notify listeners of a change in the info property
Sourcepub fn notify_user_id_string(&self)
pub fn notify_user_id_string(&self)
Notify listeners of a change in the user-id-string property
Sourcepub fn notify_homeserver_string(&self)
pub fn notify_homeserver_string(&self)
Notify listeners of a change in the homeserver-string property
Sourcepub fn notify_device_id_string(&self)
pub fn notify_device_id_string(&self)
Notify listeners of a change in the device-id-string property
Sourcepub fn notify_session_id(&self)
pub fn notify_session_id(&self)
Notify listeners of a change in the session-id property
Sourcepub fn notify_avatar_data(&self)
pub fn notify_avatar_data(&self)
Notify listeners of a change in the avatar-data property